pub struct CommonArguments {
pub entries: Option<Vec<String>>,
pub dir: Option<PathBuf>,
pub root: Option<PathBuf>,
pub log_level: Option<IssueSeverityCliOption>,
pub show_all: bool,
pub log_detail: bool,
pub full_stats: bool,
pub target: Option<Target>,
pub worker_threads: Option<usize>,
pub persistent_caching: bool,
pub cache_dir: Option<PathBuf>,
}Fields
entries: Option<Vec<String>>The entrypoints of the project. Resolved relative to the project’s
directory (--dir).
dir: Option<PathBuf>The directory of the application. If no directory is provided, the current directory will be used.
root: Option<PathBuf>The root directory of the project. Nothing outside of this directory can
be accessed. e. g. the monorepo root.
If no directory is provided, dir will be used.
log_level: Option<IssueSeverityCliOption>Filter by issue severity.
show_all: boolShow all log messages without limit.
log_detail: boolExpand the log details.
full_stats: boolWhether to enable full task stats recording in Turbo Engine.
target: Option<Target>Whether to build for the browser or node
worker_threads: Option<usize>Number of worker threads to use for parallel processing
persistent_caching: boolEnable filesystem-backed persistent caching.
Cache is stored at <cache-dir>/<git-version>.
cache_dir: Option<PathBuf>Directory to store the persistent cache.
Defaults to .turbopack/cache relative to the project directory.